==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/zh-cn.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'zh-cn', {
	acccessKey: '访问键',
	advanced: '高级',
	advisoryContentType: '内容类型',
	advisoryTitle: '标题',
	anchor: {
		toolbar: '插入/编辑锚点链接',
		menu: '锚点链接属性',
		title: '锚点链接属性',
		name: '锚点名称',
		errorName: '请输入锚点名称',
		remove: '删除锚点'
	},
	anchorId: '按锚点 ID',
	anchorName: '按锚点名称',
	charset: '字符编码',
	cssClasses: '样式类名称',
	download: '强制下载',
	displayText: '显示文本',
	emailAddress: '地址',
	emailBody: '内容',
	emailSubject: '主题',
	id: 'ID',
	info: '超链接信息',
	langCode: '语言代码',
	langDir: '语言方向',
	langDirLTR: '从左到右 (LTR)',
	langDirRTL: '从右到左 (RTL)',
	menu: '编辑超链接',
	name: '名称',
	noAnchors: '(此文档没有可用的锚点)',
	noEmail: '请输入电子邮件地址',
	noUrl: '请输入超链接地址',
	noTel: '请输入电话号码',
	other: '<其他>',
	phoneNumber: '电话号码',
	popupDependent: '依附 (NS)',
	popupFeatures: '弹出窗口属性',
	popupFullScreen: '全屏 (IE)',
	popupLeft: '左',
	popupLocationBar: '地址栏',
	popupMenuBar: '菜单栏',
	popupResizable: '可缩放',
	popupScrollBars: '滚动条',
	popupStatusBar: '状态栏',
	popupToolbar: '工具栏',
	popupTop: '右',
	rel: '关联',
	selectAnchor: '选择一个锚点',
	styles: '行内样式',
	tabIndex: 'Tab 键次序',
	target: '目标',
	targetFrame: '<框架>',
	targetFrameName: '目标框架名称',
	targetPopup: '<弹出窗口>',
	targetPopupName: '弹出窗口名称',
	title: '超链接',
	toAnchor: '页内锚点链接',
	toEmail: '电子邮件',
	toUrl: '地址',
	toPhone: '电话',
	toolbar: '插入/编辑超链接',
	type: '超链接类型',
	unlink: '取消超链接',
	upload: '上传'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/zh-cn.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'zh-cn', {
	acccessKey: '访问键',
	advanced: '高级',
	advisoryContentType: '内容类型',
	advisoryTitle: '标题',
	anchor: {
		toolbar: '插入/编辑锚点链接',
		menu: '锚点链接属性',
		title: '锚点链接属性',
		name: '锚点名称',
		errorName: '请输入锚点名称',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: '删除锚点'
	},
	anchorId: '按锚点 ID',
	anchorName: '按锚点名称',
	charset: '字符编码',
	cssClasses: '样式类名称',
	download: '强制下载',
	displayText: '显示文本',
	emailAddress: '地址',
	emailBody: '内容',
	emailSubject: '主题',
	id: 'ID',
	info: '超链接信息',
	langCode: '语言代码',
	langDir: '语言方向',
	langDirLTR: '从左到右 (LTR)',
	langDirRTL: '从右到左 (RTL)',
	menu: '编辑超链接',
	name: '名称',
	noAnchors: '(此文档没有可用的锚点)',
	noEmail: '请输入电子邮件地址',
	noUrl: '请输入超链接地址',
	noTel: '请输入电话号码',
	other: '<其他>',
	phoneNumber: '电话号码',
	popupDependent: '依附 (NS)',
	popupFeatures: '弹出窗口属性',
	popupFullScreen: '全屏 (IE)',
	popupLeft: '左',
	popupLocationBar: '地址栏',
	popupMenuBar: '菜单栏',
	popupResizable: '可缩放',
	popupScrollBars: '滚动条',
	popupStatusBar: '状态栏',
	popupToolbar: '工具栏',
	popupTop: '右',
	rel: '关联',
	selectAnchor: '选择一个锚点',
	styles: '行内样式',
	tabIndex: 'Tab 键次序',
	target: '目标',
	targetFrame: '<框架>',
	targetFrameName: '目标框架名称',
	targetPopup: '<弹出窗口>',
	targetPopupName: '弹出窗口名称',
	title: '超链接',
	toAnchor: '页内锚点链接',
	toEmail: '电子邮件',
	toUrl: '地址',
	toPhone: '电话',
	toolbar: '插入/编辑超链接',
	type: '超链接类型',
	unlink: '取消超链接',
	upload: '上传'
} );
